@@ -1,7 +1,7 @@
 """Wykop API parsers module."""
 from wykop.api.exceptions import default_exception_resolver
 from wykop.core.parsers.json import JSONParser
-from wykop.api.models import WykopAPIResponse
+from wykop.api.models.models import WykopAPIResponse
 
 default_parser = JSONParser(
     default_exception_resolver,
