@@ -1,5 +1,11 @@
 """Wykop API JSON praser module."""
 from __future__ import absolute_import
+
+import base64
+
+from wykop.api.models.wykop_connect import WykopConnectLoginInfo
+from wykop.utils import force_bytes
+
 try:
     import simplejson as json
 except ImportError:
@@ -34,3 +40,8 @@ class JSONParser(BaseParser):
             message = error_data.get('message_en')
 
         return Error(code, message)
+
+    def parse_wykop_connect_response(self, response) -> WykopConnectLoginInfo:
+        decoded_response = base64.b64decode(force_bytes(response)).decode('utf-8')
+        field_dict = json.loads(decoded_response)
+        return WykopConnectLoginInfo(**field_dict)
